@@ -91,9 +91,13 @@ cheese_gconf_get_property (GObject *object, guint prop_id, GValue *value,
           }
         }
         if (effects == NULL)
-          effects = str;
+          effects = g_strdup (str);
         else
+        {
+          gchar *dummy = effects;
           effects = g_strjoin (",", effects, str, NULL);
+          g_free (dummy);
+        }
 
         g_free (tmp->data);
         tmp = g_slist_next (tmp);
@@ -113,6 +117,46 @@ cheese_gconf_get_property (GObject *object, guint prop_id, GValue *value,
                                                     CHEESE_GCONF_PREFIX "/y_resolution",
                                                     NULL));
       break;
+    case GCONF_PROP_BRIGHTNESS:
+      if (!gconf_client_get (priv->client,
+                             CHEESE_GCONF_PREFIX "/brightness",
+                             NULL))
+        g_value_set_double (value, G_PARAM_SPEC_DOUBLE (pspec)->default_value);
+      else
+        g_value_set_double (value, gconf_client_get_float (priv->client,
+                                                           CHEESE_GCONF_PREFIX "/brightness",
+                                                           NULL));
+      break;
+    case GCONF_PROP_CONTRAST:
+      if (!gconf_client_get (priv->client,
+                             CHEESE_GCONF_PREFIX "/contrast",
+                             NULL))
+        g_value_set_double (value, G_PARAM_SPEC_DOUBLE (pspec)->default_value);
+      else
+        g_value_set_double (value, gconf_client_get_float (priv->client,
+                                                           CHEESE_GCONF_PREFIX "/contrast",
+                                                           NULL));
+      break;
+    case GCONF_PROP_SATURATION:
+      if (!gconf_client_get (priv->client,
+                             CHEESE_GCONF_PREFIX "/saturation",
+                             NULL))
+        g_value_set_double (value, G_PARAM_SPEC_DOUBLE (pspec)->default_value);
+      else
+        g_value_set_double (value, gconf_client_get_float (priv->client,
+                                                           CHEESE_GCONF_PREFIX "/saturation",
+                                                           NULL));
+      break;
+    case GCONF_PROP_HUE:
+      if (!gconf_client_get (priv->client,
+                             CHEESE_GCONF_PREFIX "/hue",
+                             NULL))
+        g_value_set_double (value, G_PARAM_SPEC_DOUBLE (pspec)->default_value);
+      else
+        g_value_set_double (value, gconf_client_get_float (priv->client,
+                                                           CHEESE_GCONF_PREFIX "/hue",
+                                                           NULL));
+      break;
     case GCONF_PROP_VIDEO_PATH:
       g_value_set_string (value, gconf_client_get_string (priv->client,
                                                           CHEESE_GCONF_PREFIX "/video_path",
@@ -128,6 +172,16 @@ cheese_gconf_get_property (GObject *object, guint prop_id, GValue *value,
                                                          CHEESE_GCONF_PREFIX "/enable_delete",
                                                          NULL));
       break;
+    case GCONF_PROP_BURST_DELAY:
+      g_value_set_int (value, gconf_client_get_int (priv->client,
+                                                    CHEESE_GCONF_PREFIX "/burst_delay",
+                                                    NULL));
+      break;
+    case GCONF_PROP_BURST_REPEAT:
+      g_value_set_int (value, gconf_client_get_int (priv->client,
+                                                    CHEESE_GCONF_PREFIX "/burst_repeat",
+                                                    NULL));
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -213,6 +267,30 @@ cheese_gconf_set_property (GObject *object, guint prop_id, const GValue *value,
                             g_value_get_int (value),
                             NULL);
       break;
+    case GCONF_PROP_BRIGHTNESS:
+      gconf_client_set_float (priv->client,
+                              CHEESE_GCONF_PREFIX "/brightness",
+                              g_value_get_double (value),
+                              NULL);
+      break;
+    case GCONF_PROP_CONTRAST:
+      gconf_client_set_float (priv->client,
+                              CHEESE_GCONF_PREFIX "/contrast",
+                              g_value_get_double (value),
+                              NULL);
+      break;
+    case GCONF_PROP_SATURATION:
+      gconf_client_set_float (priv->client,
+                              CHEESE_GCONF_PREFIX "/saturation",
+                              g_value_get_double (value),
+                              NULL);
+      break;
+    case GCONF_PROP_HUE:
+      gconf_client_set_float (priv->client,
+                              CHEESE_GCONF_PREFIX "/hue",
+                              g_value_get_double (value),
+                              NULL);
+      break;
     case GCONF_PROP_VIDEO_PATH:
       gconf_client_set_string (priv->client,
                                CHEESE_GCONF_PREFIX "/video_path",
@@ -231,6 +309,18 @@ cheese_gconf_set_property (GObject *object, guint prop_id, const GValue *value,
                              g_value_get_boolean (value),
                              NULL);
       break;
+    case GCONF_PROP_BURST_DELAY:
+      gconf_client_set_int (priv->client,
+                            CHEESE_GCONF_PREFIX "/burst_delay",
+                            g_value_get_int (value),
+                            NULL);
+      break;
+    case GCONF_PROP_BURST_REPEAT:
+      gconf_client_set_int (priv->client,
+                            CHEESE_GCONF_PREFIX "/burst_repeat",
+                            g_value_get_int (value),
+                            NULL);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -296,6 +386,42 @@ cheese_gconf_class_init (CheeseGConfClass *klass)
                                                      0,
                                                      G_PARAM_READWRITE));
 
+  g_object_class_install_property (object_class, GCONF_PROP_BRIGHTNESS,
+                                   g_param_spec_double ("gconf_prop_brightness",
+                                                        NULL,
+                                                        NULL,
+                                                        -G_MAXFLOAT,
+                                                        G_MAXFLOAT,
+                                                        0.0,
+                                                        G_PARAM_READWRITE));
+
+  g_object_class_install_property (object_class, GCONF_PROP_CONTRAST,
+                                   g_param_spec_double ("gconf_prop_contrast",
+                                                        NULL,
+                                                        NULL,
+                                                        0,
+                                                        G_MAXFLOAT,
+                                                        1.0,
+                                                        G_PARAM_READWRITE));
+
+  g_object_class_install_property (object_class, GCONF_PROP_SATURATION,
+                                   g_param_spec_double ("gconf_prop_saturation",
+                                                        NULL,
+                                                        NULL,
+                                                        0,
+                                                        G_MAXFLOAT,
+                                                        1.0,
+                                                        G_PARAM_READWRITE));
+
+  g_object_class_install_property (object_class, GCONF_PROP_HUE,
+                                   g_param_spec_double ("gconf_prop_hue",
+                                                        NULL,
+                                                        NULL,
+                                                        -G_MAXFLOAT,
+                                                        G_MAXFLOAT,
+                                                        0.0,
+                                                        G_PARAM_READWRITE));
+
   g_object_class_install_property (object_class, GCONF_PROP_VIDEO_PATH,
                                    g_param_spec_string ("gconf_prop_video_path",
                                                         NULL,
@@ -317,6 +443,23 @@ cheese_gconf_class_init (CheeseGConfClass *klass)
                                                          FALSE,
                                                          G_PARAM_READWRITE));
 
+  g_object_class_install_property (object_class, GCONF_PROP_BURST_DELAY,
+                                   g_param_spec_int ("gconf_prop_burst_delay",
+                                                     NULL,
+                                                     NULL,
+                                                     200,  /* based on some experiments */
+                                                     G_MAXINT,
+                                                     1000,
+                                                     G_PARAM_READWRITE));
+
+  g_object_class_install_property (object_class, GCONF_PROP_BURST_REPEAT,
+                                   g_param_spec_int ("gconf_prop_burst_repeat",
+                                                     NULL,
+                                                     NULL,
+                                                     1,
+                                                     G_MAXINT,
+                                                     4,
+                                                     G_PARAM_READWRITE));
 
   g_type_class_add_private (klass, sizeof (CheeseGConfPrivate));
 }
